pro shapelets_geometric_contstraints, pstamp, th_min_geom, th_max_geom, x0=x0

;$Id: shapelets_geometric_contstraints.pro, v2$
;
; Copyright  2005 Richard Massey and Alexandre Refregier.
;
; This file is a part of the Shapelets analysis code.
; www.astro.caltech.edu/~rjm/shapelets/
;
; The Shapelets code is free software; you can redistribute it and/or
; modify it under the terms of the GNU General Public Licence as published
; by the Free Software Foundation; either version 2 of the Licence, or
; (at your option) any later version.
;
; The Shapelets code is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
; GNU General Public Licence for more details.
;
; You should have received a copy of the GNU General Public Licence
; along with the Shapelets code; if not, write to the Free Software
; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
;
;+
; NAME:
;      SHAPELETS_GEOMETRIC_CONTSTRAINTS
;
; PURPOSE:
;      Determine theta_min and theta_max for an object.
;
; CATEGORY:
;      Shapelets.
;
; INPUTS:
;      pstamp - IDL "pstamp" structure containing a single object from an image.
;
; OPTIONAL INPUTS:
;      th_min_geom - minimum scale for geometrical constraint.
;                    (default: 0.2 pixels)
;      x0          - centre of shapelet basis functions.
;
; KEYWORD PARAMETERS:
;      None.
;
; OUTPUTS:
;      th_min_geom - minimum scale for geometrical constraint.
;      th_max_geom - maximum scale for geometrical constraint.
;      
; MODIFICATION HISTORY:
;      Jan 05 - Written by Richard Massey
;-

COMPILE_OPT idl2

; Guess centroid using sextractor centroid
if not keyword_set(x0) then x0=[pstamp.xo,pstamp.yo]

; Guess th_min_geom as the rms of a square pixel (0.166)
if not keyword_set(th_min_geom) then th_min_geom=0.2

; Guess th_max_geom
n_pixels=[pstamp.im_ran[1]-pstamp.im_ran[0],pstamp.im_ran[3]-pstamp.im_ran[2]]
case strupcase(pstamp.geometry) of
  "SQUARE": th_max_geom=min([x0[0],n_pixels[0]-x0[0],x0[1],n_pixels[1]-x0[1]])
  "CIRCLE": begin
              radius=total(n_pixels)/4.
              centre=n_pixels/2.
              dist_to_centre=sqrt((x0[0]-centre[0])^2+(x0[1]-centre[1])^2)
              th_max_geom=radius-dist_to_centre
            end
  else: message,"Postage stamp geometry not recognised!"
endcase

end
