function shapelets_profile, decomp, r

;$Id: shapelets_profile.pro, v2$
;
; Copyright  2005 Richard Massey and Alexandre Refregier.
;
; This file is a part of the Shapelets analysis code.
; www.ast.cam.ac.uk/~rjm/shapelets/
;
; The Shapelets code is free software; you can redistribute it and/or
; modify it under the terms of the GNU General Public Licence as published
; by the Free Software Foundation; either version 2 of the Licence, or
; (at your option) any later version.
;
; The Shapelets code is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
; GNU General Public Licence for more details.
;
; You should have received a copy of the GNU General Public Licence
; along with the Shapelets code; if not, write to the Free Software
; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
;
;+
; NAME:
;       SHAPELETS_PROFILE
;
; PURPOSE:
;       Compute the azymuthally averaged profile f(r) of an object from 
;       its shapelet coefficients.
;
; INPUTS:
;       DECOMP - Cartesian shapelet decomp structure
;       r      - radii at which to evaluate the profile [pixels]
;
; KEYWORD PARAMETERS:
;       None.
;
; OUTPUTS:
;       f(r).
;
; MODIFICATION HISTORY:
;       Jul 05 - Completely rewritten by Richard Massey.
;       Mar 02 - Written by Alexandre Refregier.
;-

; Convert shapelet coefficients to polar format if necessary
if tag_exist(decomp,"polar") then if decomp.polar then polar_coeffs=decomp.coeffs
if n_elements(polar_coeffs) eq 0 then polar_coeffs=shapelets_polar_matrix(decomp.n_max,/c2p)#decomp.coeffs

; Extract the m=0 coefficients
shapelets_make_nvec,decomp.n_max,n,m,/POLAR
polar_coeffs=float(polar_coeffs[where(m eq 0)])

; Compute the shapelet polar radial functions
BasisF=shapelets_chi(decomp.n_max-decomp.n_max mod 2,r,beta=decomp.beta,/ARRAY)

; Reconstruct the radial profile
radial_profile=polar_coeffs##BasisF

; Tell the world
return,radial_profile

end
